@@ -107,6 +107,15 @@ class TestConnection(BadAppTestCase):
         self.assertEqual('dolphin', response.fields['Animal'])
         self.assertEqual(b'hello world!', response.body.content)
 
+    @tornado.testing.gen_test(timeout=DEFAULT_TIMEOUT)
+    def test_basic_chunked_trailer_2(self):
+        response = yield self.fetch('/chunked_trailer_2')
+        self.assertEqual(200, response.status_code)
+        self.assertEqual('chunked', response.fields['Transfer-Encoding'])
+        self.assertEqual('dolphin', response.fields['Animal'])
+        self.assertEqual('delicious', response.fields['Cake'])
+        self.assertEqual(b'hello world!', response.body.content)
+
     @tornado.testing.gen_test(timeout=DEFAULT_TIMEOUT)
     def test_malformed_chunked(self):
         try:
@@ -116,6 +125,20 @@ class TestConnection(BadAppTestCase):
         else:
             self.fail()
 
+    @tornado.testing.gen_test(timeout=DEFAULT_TIMEOUT)
+    def test_non_standard_delim_chunked(self):
+        response = yield self.fetch('/chunked_non_standard_delim')
+        self.assertEqual(200, response.status_code)
+        self.assertEqual('chunked', response.fields['Transfer-Encoding'])
+        self.assertEqual(b'hello world!', response.body.content)
+
+    @tornado.testing.gen_test(timeout=DEFAULT_TIMEOUT)
+    def test_chunked_with_extension(self):
+        response = yield self.fetch('/chunked_with_extension')
+        self.assertEqual(200, response.status_code)
+        self.assertEqual('chunked', response.fields['Transfer-Encoding'])
+        self.assertEqual(b'hello world!', response.body.content)
+
     @tornado.testing.gen_test(timeout=DEFAULT_TIMEOUT)
     def test_buffer_overflow(self):
         connection = Connection('localhost', self._port,
@@ -242,6 +265,13 @@ class TestConnection(BadAppTestCase):
             DebugPrintRecorder()
         )
 
+    @unittest.skip('Reenable when issue #53 is being fixed')
+    @tornado.testing.gen_test(timeout=DEFAULT_TIMEOUT)
+    def test_big(self):
+        self.connection.fetch(
+            Request.new(self.get_url('/big')),
+        )
+
 
 class TestClient(BadAppTestCase):
     def setUp(self):
